import re
from lr1110evk.BaseTypes import Coordinate


class ExternalCoordinateException(Exception):
    pass


class ExternalCoordinateMalformedCsvLineException(ExternalCoordinateException):
    def __init__(self, csv_line):
        self.malformed_csv_line = csv_line

    def __str__(self):
        return "Failed to convert to external coordinate the csv line '{}'".format(
            self.malformed_csv_line
        )


class ExternalCoordinate:
    regexp_csv_line = re.compile(
        "^(?P<external_id>[a-zA-Z0-9]+): (?P<coordinate>[0-9,.-]+)$"
    )

    def __init__(self, external_id, coordinate):
        self.coordinate = coordinate
        self.external_id = external_id

    @staticmethod
    def from_csv_line(csv_line):
        match_line = ExternalCoordinate.regexp_csv_line.match(csv_line.strip())
        if match_line:
            external_id = match_line.group("external_id")
            coordinate = Coordinate.from_string(match_line.group("coordinate"))
            return ExternalCoordinate(external_id=external_id, coordinate=coordinate)
        else:
            raise ExternalCoordinateMalformedCsvLineException(csv_line)

    def __repr__(self):
        return "ExternalCoordinate<external_id={}, coordinate={}>".format(
            self.external_id, self.coordinate
        )
