from argparse import ArgumentParser
import pkg_resources
from lr1110evk.NavParserFile.FileNavMessageParser import FileNavMessageParserInterpreter
from NavParser.NavMessageParser import NavMessageParser

def entry_point_nav_parser_file():
    version = pkg_resources.get_distribution("lr1110evk").version
    parser = ArgumentParser(description="Host companion for field tests of LR1110")
    parser.add_argument("--version", action="version", version=version)
    parser.add_argument(
        "-m",
        "--nav-message",
        help="The input_file is not a file to read but a NAV message to interpret",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "-o",
        "--output_file",
        help="File to write containing the interpreted NAV messages instead of printing on stout (does nothing if -m is provided)",
    )
    parser.add_argument(
        "input_file",
        help="File to read to extract and interpret NAV messages (or NAV message if -m is provided). Format of the file content is the same as the one provided by Lr1110FieldTest output",
    )
    args = parser.parse_args()

    if not args.nav_message:
        file_interpreter = FileNavMessageParserInterpreter(args.input_file, args.output_file)
        file_interpreter.parse_file()
    else:
        # In this case, args.input_file is not the result file to read, but a string representing a nav message to interpret
        nav_parsed = NavMessageParser.parse(args.input_file)
        sv_cn = NavMessageParser.get_cn_vs_from_parsed_message(nav_parsed)
        print("Satellite Name, C/N indicator")
        for sv_id, cn in sv_cn.items():
            print("{}, {}".format(sv_id, cn))
