from .ResponseBase import ResponseBase


class ResponseAlmanacDates(ResponseBase):
    SIZE_SAT_AGE_RAW_BYTES = 3

    def __init__(self, reception_time, almanac_age_per_satellites):
        super().__init__(reception_time)
        self.almanac_age_per_satellites = almanac_age_per_satellites

    def __str__(self):
        return "Almanacs:\n{}".format(
            ";".join(
                [
                    "{}: {}".format(sat, age)
                    for sat, age in self.almanac_age_per_satellites.items()
                ]
            )
        )

    @classmethod
    def get_response_code(cls):
        return b"\x07\x00"

    @classmethod
    def from_response_raw(cls, response_raw):
        reception_time = response_raw.receive_time

        almanac_age_per_satellites = dict()
        for raw_sat_date in ResponseAlmanacDates.chunker(
            response_raw.payload_bytes, ResponseAlmanacDates.SIZE_SAT_AGE_RAW_BYTES
        ):
            satellite_id = raw_sat_date[0]
            age = (raw_sat_date[1] << 8) + raw_sat_date[2]
            almanac_age_per_satellites[satellite_id] = age

        response = ResponseAlmanacDates(
            reception_time=reception_time,
            almanac_age_per_satellites=almanac_age_per_satellites,
        )
        return response

    @staticmethod
    # From https://stackoverflow.com/a/434328
    def chunker(sequence, size):
        for pos in range(0, len(sequence), size):
            yield sequence[pos : pos + size]
