from .ResponseBase import ResponseBase


class ResponseVersion(ResponseBase):
    def __init__(
        self,
        reception_time,
        software_version,
        driver_version,
        lr1110_hw_version,
        lr1110_type,
        lr1110_firmware_version,
        almanac_crc,
        chip_uid,
    ):
        super().__init__(reception_time)
        self.software_version = software_version
        self.driver_version = driver_version
        self.lr1110_hw_version = lr1110_hw_version
        self.lr1110_type = lr1110_type
        self.lr1110_firmware_version = lr1110_firmware_version
        self.almanac_crc = almanac_crc
        self.chip_uid = chip_uid

    def __str__(self):
        return "Version: software: {}, LR1110 HW: {}, LR1110 FW: {}, almanac crc: {}, chip uid: {}".format(
            self.software_version,
            self.lr1110_hw_version,
            self.lr1110_firmware_version,
            self.almanac_crc,
            self.chip_uid,
        )

    @classmethod
    def get_response_code(cls):
        return b"\x06\x00"

    @classmethod
    def from_response_raw(cls, response_raw):
        reception_time = response_raw.receive_time
        (
            software_version,
            driver_version_raw,
            lr1110_hw_version_raw,
            lr1110_type_raw,
            lr1110_firmware_version_raw,
            almanac_crc_raw,
            chip_uid,
        ) = response_raw.payload_bytes.split(b";")
        response = ResponseVersion(
            reception_time=reception_time,
            software_version=software_version.decode(),
            driver_version=driver_version_raw.decode(),
            lr1110_hw_version=lr1110_hw_version_raw.decode(),
            lr1110_type=lr1110_type_raw.decode(),
            lr1110_firmware_version=lr1110_firmware_version_raw.decode(),
            almanac_crc=almanac_crc_raw.decode(),
            chip_uid=chip_uid.decode()
        )
        return response
