from threading import Thread
from .SerialHandler import SerialHandler


class SerialHandlerConnectionTest(SerialHandler):
    TEST_HOST_CONNECTION_TEST_RESPONSE = b"testdglog\x00"
    EXPECTED_RESPONSE_FROM_EMBEDDED = b"It works !"

    def __init__(self):
        super().__init__()
        self.read_thread = Thread(
            name="SerialRead",
            target=SerialHandlerConnectionTest.read_command,
            args=(self,),
        )

    def read_command(self):
        print("Waiting for embedded to send command...")
        while not self.read_thread_run.is_set():
            line = self.read_one_line()
            if line:
                if line.startswith(SerialHandler.TEST_HOST_MESSAGE.decode("utf-8")):
                    # Test message received
                    self.serial_port.write(
                        SerialHandlerConnectionTest.TEST_HOST_CONNECTION_TEST_RESPONSE
                    )
                    print("Got message from embedded. Sending question...")
                elif line.startswith(
                    SerialHandlerConnectionTest.EXPECTED_RESPONSE_FROM_EMBEDDED.decode(
                        "utf-8"
                    )
                ):
                    print("Got response from embedded. Communication ok.")
                else:
                    print(
                        "Unexpected data received from embedded: '{}'. Communication KO!".format(
                            line
                        )
                    )
        print("Leaving runtime")

    def read_one_line(self):
        try:
            line = self.serial_port.readline().decode("ascii")
        except UnicodeDecodeError:
            print("Error on USB line. Communication KO!")
            line = None
        return line


def launch_test():
    from time import sleep

    serial_handler = SerialHandlerConnectionTest()
    port = serial_handler.discover(SerialHandler.DISCOVER_PORT_REGEXP)
    serial_handler.set_serial_port(port.device)

    print("Started")
    serial_handler.start_read()

    try:
        while True:
            sleep(2)
    except KeyboardInterrupt:
        serial_handler.stop_read()
    finally:
        print("Bye")


def entry_point_connection_tester():
    import pkg_resources
    from argparse import ArgumentParser

    version = pkg_resources.get_distribution("lr1110evk").version
    parser = ArgumentParser(
        description="Companion software of LR1110 Dev Kit. Check the USB connection with a dedicated embedded software that do not require the LR1110 shield to be connected."
    )
    parser.add_argument("--version", action="version", version=version)
    parser.parse_args()

    launch_test()


if __name__ == "__main__":
    launch_test()
