from unittest import TestCase
from parameterized import parameterized
from lr1110evk.FieldTestPost.Core.FileReader import FileReader
from NavParser.navParser.core import SatelliteResults
from NavParser import (
    NavMessageParser,
    CnRangeVeryHigh,
    CnRangeHigh,
    CnRangeLow,
    CnRangeVeryLow
)
from pprint import pprint


class NavParserTestCase(TestCase):
    def test_parse_from_file_reader(self):
        csv_line = "[2019-10-21 12:42:58.751156] [3 - 0] 0101AAAA070808e210a8ef20e22e0014529bec007d0080a4522becb70e20513d41e5e9dd45b05a2115da3b8b67957d73c8f498caaa216e9aec23, 0, 0, 0"
        expected_results_raw = {2: CnRangeVeryLow.get_name(), 5: CnRangeHigh.get_name(), 8: CnRangeVeryHigh.get_name(), 16: CnRangeHigh.get_name(), 18: CnRangeLow.get_name(), 21: CnRangeVeryLow.get_name(), 30: CnRangeVeryLow.get_name()}

        expected_results = {
            SatelliteResults.satellite_id_to_name(sv_id): c_n for sv_id, c_n in expected_results_raw.items()
        }

        scanned_result_line = FileReader.get_scan_info_and_job_data_from_line(csv_line)
        parsed_nav = NavMessageParser.parse(scanned_result_line.scan_info.nav_message)
        sv_vs_cn = NavMessageParser.get_cn_vs_from_parsed_message(parsed_nav)
        self.assertDictEqual(expected_results, sv_vs_cn)